@@ -27,7 +27,7 @@
 #
 #========================================================================
 #
-# Version 4.3.2, released 17 Feb 2020.
+# Version 4.4.0, released 20 Jun 2020.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -50,8 +50,7 @@ sub action
     my(%EmailStr, $str);
     foreach my $u ( keys(%UserEmailInfo) ) {
         my $info;
-        if ( defined($UserEmailInfo{$u}{lastTime})
-                && ref($UserEmailInfo{$u}{lastTime}) ne 'HASH' ) {
+        if ( defined($UserEmailInfo{$u}{lastTime}) && ref($UserEmailInfo{$u}{lastTime}) ne 'HASH' ) {
             #
             # old format $UserEmailInfo - pre 3.2.0.
             #
@@ -76,7 +75,7 @@ sub action
 EOF
         }
     }
-    foreach my $t ( sort({$b <=> $a} keys(%EmailStr)) ) {
+    foreach my $t ( sort({ $b <=> $a } keys(%EmailStr)) ) {
         $str .= $EmailStr{$t};
     }
     my $content = eval("qq{$Lang->{Recent_Email_Summary}}");
